## [v0.1.1] - 2025-08-28

### Fixed

- Fix incorrect parameter type in `afp.bindings.ClearingDiamond.mutializeLosses` ([#8](https://github.com/autonity/afp-sdk/pull/8))

## [v0.1.0] - 2025-08-22

_First release._

[v0.1.1]: https://github.com/autonity/afp-sdk/releases/tag/v0.1.1
[v0.1.0]: https://github.com/autonity/afp-sdk/releases/tag/v0.1.0
